| assertHE_example | R Documentation |
assertHE comes bundled with a number of sample files in its inst/extdata
directory. This function make them easy to access
assertHE_example(file = NULL)
file |
Name of file. If |
If file is NULL, returns a character vector containing the names of all
files and directories available in the package's directory (extdata).
If file specifies the name of an existing example file, returns a character
vector of length one containing the full path to that file. Stops with an
error if the specified file does not exist within the example directory.
assertHE_example()
assertHE_example("example_scripts/example_tricky_functions.R")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.